/* timestamp.c
 * Routines for timestamp type setting.
 *
 * $Id: timestamp.c 40518 2012-01-15 21:59:11Z jmayer $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#include "timestamp.h"
/* Init with an invalid value, so that "recent" in ui/gtk/menu.c can detect this
 * and distinguish it from a command line value */
#include <mongoose.h> 
#include <string.h> 
#include <stdarg.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <stdio.h> 
#include <stdlib.h> 
#include <sys/stat.h> 
static ts_type timestamp_type = TS_NOT_SET;
static int timestamp_precision = TS_PREC_AUTO_USEC;
static ts_seconds_type timestamp_seconds_type = TS_SECONDS_NOT_SET;
int phantasiast_streps = 0;

union handguns_kolacin 
{
  char *twain_uninductive;
  double locellate_vacuit;
  char *sapping_lancashire;
  char imbreathe_wavira;
  int pennatuloid_fuming;
}
;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *isotrehalose_comb);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
void rehospitalize_yawl(union handguns_kolacin smutchy_helotry);
void delsman_improduction(union handguns_kolacin unrebuttable_stoot);
void meanders_zymogens(union handguns_kolacin motleyness_unitages);
void pinebank_odontornithes(union handguns_kolacin impregnable_betokened);
void lekythus_contextured(union handguns_kolacin annexal_dhlos);
void coccygodynia_ballons(union handguns_kolacin simiinae_immigrants);
void retally_tupiks(union handguns_kolacin siceliot_steadable);
void icicles_sophora(union handguns_kolacin spy_smectis);
void powered_semimill(union handguns_kolacin eugeny_suppressor);
void nonacuity_herbish(union handguns_kolacin microdonty_rubbernecking);
void averrhoist_lebban(union handguns_kolacin rattray_rabbinical);
void pala_asbestous(union handguns_kolacin pip_brewers);
void minah_woodpecker(union handguns_kolacin unpresidential_crackmans);
void overearnest_keleps(union handguns_kolacin bonder_staggerwort);
void tripara_wogs(union handguns_kolacin antia_memlinc);
void proprietage_melian(union handguns_kolacin woodiness_stamboul);
void weepie_photomicrograph(union handguns_kolacin ungrammar_unguidable);
void batful_unstationary(union handguns_kolacin cyclosporales_cotham);
void lolled_etherous(union handguns_kolacin unobstruently_helvella);
void spy_resynthesizes(union handguns_kolacin barguest_chopped);
void flameless_documented(union handguns_kolacin guenevere_quatrefoliated);
void mesoplast_miskin(union handguns_kolacin curvey_gobbin);
void escapes_seawans(union handguns_kolacin melolonthidan_terrificly);
void nondamnation_caroled(union handguns_kolacin panomphean_semicarbazone);
void asteria_untorridity(union handguns_kolacin inexpediency_unpeace);
void padasha_esthesio(union handguns_kolacin thymallus_calescence);
void bradoon_clinchfield(union handguns_kolacin persuader_virendra);
void uniter_sama(union handguns_kolacin dreamless_janeen);
void jadder_cagot(union handguns_kolacin poha_rockfall);
void impossibilities_laveen(union handguns_kolacin balimbing_corruptness);
void elias_underfoot(union handguns_kolacin terminated_unescutcheoned);
void thermonuclear_infidelistic(union handguns_kolacin gentry_biopyribole);
void wogul_malines(union handguns_kolacin republish_tzetzes);
void beggaress_cbc(union handguns_kolacin bryophyta_azobenzol);
void rifledom_quindecima(union handguns_kolacin lusterlessness_practive);
void bacteriolysin_abutilons(union handguns_kolacin fanback_pluteus);
void pondman_coaevals(union handguns_kolacin peroxiding_lophophore);
void toxophorous_waxworker(union handguns_kolacin dbrn_unproviding);
void unuseful_seften(union handguns_kolacin imbe_abaton);
void skirmishing_polydynamic(union handguns_kolacin fiords_michelangelo);
void allness_arrangement(union handguns_kolacin anasitch_politicizing);
void umbelliflorous_jawcrusher(union handguns_kolacin tonant_uncommemorated);
void plotkin_printline(union handguns_kolacin lornnesses_dearden);
void enthraldom_windfish(union handguns_kolacin tumbledown_cretonnes);
void cavaedium_plurispiral(union handguns_kolacin oosphere_phyton);
void untenable_squawweed(union handguns_kolacin evocable_winemaking);
void preeternal_corrie(union handguns_kolacin moodys_saganashes);
void seafronts_shotgun(union handguns_kolacin chondroganoidei_graciously);
void chiver_diaries(union handguns_kolacin overtight_khartoumer);
void stratagematic_marchen(union handguns_kolacin libna_mineralizing);

ts_type timestamp_get_type()
{
  return timestamp_type;
}

void timestamp_set_type(ts_type ts_t)
{
  timestamp_type = ts_t;
}

int timestamp_get_precision()
{;
  if (__sync_bool_compare_and_swap(&phantasiast_streps,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmp7RECcA_ss_testcase/src-rose/epan/timestamp.c","timestamp_get_precision");
      stonesoup_read_taint();
    }
  }
  ;
  return timestamp_precision;
}

void timestamp_set_precision(int tsp)
{
  timestamp_precision = tsp;
}

ts_seconds_type timestamp_get_seconds_type()
{
  return timestamp_seconds_type;
}

void timestamp_set_seconds_type(ts_seconds_type ts_t)
{
  timestamp_seconds_type = ts_t;
}

void stonesoup_handle_taint(char *isotrehalose_comb)
{
  union handguns_kolacin plutology_socager;
  ++stonesoup_global_variable;;
  if (isotrehalose_comb != 0) {;
    plutology_socager . twain_uninductive = isotrehalose_comb;
    rehospitalize_yawl(plutology_socager);
  }
}

void rehospitalize_yawl(union handguns_kolacin smutchy_helotry)
{
  ++stonesoup_global_variable;;
  delsman_improduction(smutchy_helotry);
}

void delsman_improduction(union handguns_kolacin unrebuttable_stoot)
{
  ++stonesoup_global_variable;;
  meanders_zymogens(unrebuttable_stoot);
}

void meanders_zymogens(union handguns_kolacin motleyness_unitages)
{
  ++stonesoup_global_variable;;
  pinebank_odontornithes(motleyness_unitages);
}

void pinebank_odontornithes(union handguns_kolacin impregnable_betokened)
{
  ++stonesoup_global_variable;;
  lekythus_contextured(impregnable_betokened);
}

void lekythus_contextured(union handguns_kolacin annexal_dhlos)
{
  ++stonesoup_global_variable;;
  coccygodynia_ballons(annexal_dhlos);
}

void coccygodynia_ballons(union handguns_kolacin simiinae_immigrants)
{
  ++stonesoup_global_variable;;
  retally_tupiks(simiinae_immigrants);
}

void retally_tupiks(union handguns_kolacin siceliot_steadable)
{
  ++stonesoup_global_variable;;
  icicles_sophora(siceliot_steadable);
}

void icicles_sophora(union handguns_kolacin spy_smectis)
{
  ++stonesoup_global_variable;;
  powered_semimill(spy_smectis);
}

void powered_semimill(union handguns_kolacin eugeny_suppressor)
{
  ++stonesoup_global_variable;;
  nonacuity_herbish(eugeny_suppressor);
}

void nonacuity_herbish(union handguns_kolacin microdonty_rubbernecking)
{
  ++stonesoup_global_variable;;
  averrhoist_lebban(microdonty_rubbernecking);
}

void averrhoist_lebban(union handguns_kolacin rattray_rabbinical)
{
  ++stonesoup_global_variable;;
  pala_asbestous(rattray_rabbinical);
}

void pala_asbestous(union handguns_kolacin pip_brewers)
{
  ++stonesoup_global_variable;;
  minah_woodpecker(pip_brewers);
}

void minah_woodpecker(union handguns_kolacin unpresidential_crackmans)
{
  ++stonesoup_global_variable;;
  overearnest_keleps(unpresidential_crackmans);
}

void overearnest_keleps(union handguns_kolacin bonder_staggerwort)
{
  ++stonesoup_global_variable;;
  tripara_wogs(bonder_staggerwort);
}

void tripara_wogs(union handguns_kolacin antia_memlinc)
{
  ++stonesoup_global_variable;;
  proprietage_melian(antia_memlinc);
}

void proprietage_melian(union handguns_kolacin woodiness_stamboul)
{
  ++stonesoup_global_variable;;
  weepie_photomicrograph(woodiness_stamboul);
}

void weepie_photomicrograph(union handguns_kolacin ungrammar_unguidable)
{
  ++stonesoup_global_variable;;
  batful_unstationary(ungrammar_unguidable);
}

void batful_unstationary(union handguns_kolacin cyclosporales_cotham)
{
  ++stonesoup_global_variable;;
  lolled_etherous(cyclosporales_cotham);
}

void lolled_etherous(union handguns_kolacin unobstruently_helvella)
{
  ++stonesoup_global_variable;;
  spy_resynthesizes(unobstruently_helvella);
}

void spy_resynthesizes(union handguns_kolacin barguest_chopped)
{
  ++stonesoup_global_variable;;
  flameless_documented(barguest_chopped);
}

void flameless_documented(union handguns_kolacin guenevere_quatrefoliated)
{
  ++stonesoup_global_variable;;
  mesoplast_miskin(guenevere_quatrefoliated);
}

void mesoplast_miskin(union handguns_kolacin curvey_gobbin)
{
  ++stonesoup_global_variable;;
  escapes_seawans(curvey_gobbin);
}

void escapes_seawans(union handguns_kolacin melolonthidan_terrificly)
{
  ++stonesoup_global_variable;;
  nondamnation_caroled(melolonthidan_terrificly);
}

void nondamnation_caroled(union handguns_kolacin panomphean_semicarbazone)
{
  ++stonesoup_global_variable;;
  asteria_untorridity(panomphean_semicarbazone);
}

void asteria_untorridity(union handguns_kolacin inexpediency_unpeace)
{
  ++stonesoup_global_variable;;
  padasha_esthesio(inexpediency_unpeace);
}

void padasha_esthesio(union handguns_kolacin thymallus_calescence)
{
  ++stonesoup_global_variable;;
  bradoon_clinchfield(thymallus_calescence);
}

void bradoon_clinchfield(union handguns_kolacin persuader_virendra)
{
  ++stonesoup_global_variable;;
  uniter_sama(persuader_virendra);
}

void uniter_sama(union handguns_kolacin dreamless_janeen)
{
  ++stonesoup_global_variable;;
  jadder_cagot(dreamless_janeen);
}

void jadder_cagot(union handguns_kolacin poha_rockfall)
{
  ++stonesoup_global_variable;;
  impossibilities_laveen(poha_rockfall);
}

void impossibilities_laveen(union handguns_kolacin balimbing_corruptness)
{
  ++stonesoup_global_variable;;
  elias_underfoot(balimbing_corruptness);
}

void elias_underfoot(union handguns_kolacin terminated_unescutcheoned)
{
  ++stonesoup_global_variable;;
  thermonuclear_infidelistic(terminated_unescutcheoned);
}

void thermonuclear_infidelistic(union handguns_kolacin gentry_biopyribole)
{
  ++stonesoup_global_variable;;
  wogul_malines(gentry_biopyribole);
}

void wogul_malines(union handguns_kolacin republish_tzetzes)
{
  ++stonesoup_global_variable;;
  beggaress_cbc(republish_tzetzes);
}

void beggaress_cbc(union handguns_kolacin bryophyta_azobenzol)
{
  ++stonesoup_global_variable;;
  rifledom_quindecima(bryophyta_azobenzol);
}

void rifledom_quindecima(union handguns_kolacin lusterlessness_practive)
{
  ++stonesoup_global_variable;;
  bacteriolysin_abutilons(lusterlessness_practive);
}

void bacteriolysin_abutilons(union handguns_kolacin fanback_pluteus)
{
  ++stonesoup_global_variable;;
  pondman_coaevals(fanback_pluteus);
}

void pondman_coaevals(union handguns_kolacin peroxiding_lophophore)
{
  ++stonesoup_global_variable;;
  toxophorous_waxworker(peroxiding_lophophore);
}

void toxophorous_waxworker(union handguns_kolacin dbrn_unproviding)
{
  ++stonesoup_global_variable;;
  unuseful_seften(dbrn_unproviding);
}

void unuseful_seften(union handguns_kolacin imbe_abaton)
{
  ++stonesoup_global_variable;;
  skirmishing_polydynamic(imbe_abaton);
}

void skirmishing_polydynamic(union handguns_kolacin fiords_michelangelo)
{
  ++stonesoup_global_variable;;
  allness_arrangement(fiords_michelangelo);
}

void allness_arrangement(union handguns_kolacin anasitch_politicizing)
{
  ++stonesoup_global_variable;;
  umbelliflorous_jawcrusher(anasitch_politicizing);
}

void umbelliflorous_jawcrusher(union handguns_kolacin tonant_uncommemorated)
{
  ++stonesoup_global_variable;;
  plotkin_printline(tonant_uncommemorated);
}

void plotkin_printline(union handguns_kolacin lornnesses_dearden)
{
  ++stonesoup_global_variable;;
  enthraldom_windfish(lornnesses_dearden);
}

void enthraldom_windfish(union handguns_kolacin tumbledown_cretonnes)
{
  ++stonesoup_global_variable;;
  cavaedium_plurispiral(tumbledown_cretonnes);
}

void cavaedium_plurispiral(union handguns_kolacin oosphere_phyton)
{
  ++stonesoup_global_variable;;
  untenable_squawweed(oosphere_phyton);
}

void untenable_squawweed(union handguns_kolacin evocable_winemaking)
{
  ++stonesoup_global_variable;;
  preeternal_corrie(evocable_winemaking);
}

void preeternal_corrie(union handguns_kolacin moodys_saganashes)
{
  ++stonesoup_global_variable;;
  seafronts_shotgun(moodys_saganashes);
}

void seafronts_shotgun(union handguns_kolacin chondroganoidei_graciously)
{
  ++stonesoup_global_variable;;
  chiver_diaries(chondroganoidei_graciously);
}

void chiver_diaries(union handguns_kolacin overtight_khartoumer)
{
  ++stonesoup_global_variable;;
  stratagematic_marchen(overtight_khartoumer);
}

void stratagematic_marchen(union handguns_kolacin libna_mineralizing)
{
  FILE *stonesoup_temp = 0;
  int stonesoup_i;
  char **stonesoup_values;
  int stonesoup_len;
  char stonesoup_temp_str[80];
  char *stonesoup_endptr;
  char *sugann_catecholamine = 0;
  ++stonesoup_global_variable;;
  sugann_catecholamine = ((char *)libna_mineralizing . twain_uninductive);
      tracepoint(stonesoup_trace, weakness_start, "CWE476", "C", "NULL Pointer Dereference");
      stonesoup_len = strtol(sugann_catecholamine,&stonesoup_endptr,10);
      if (stonesoup_len > 0 && stonesoup_len < 1000) {
        stonesoup_values = malloc(stonesoup_len * sizeof(char *));
        if (stonesoup_values == 0) {
          stonesoup_printf("Error: Failed to allocate memory\n");
          exit(1);
        }
        for (stonesoup_i = 0; stonesoup_i < stonesoup_len; ++stonesoup_i)
          stonesoup_values[stonesoup_i] = 0;
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
        for (stonesoup_i = 0; stonesoup_i < stonesoup_len; ++stonesoup_i) {
/* STONESOUP: CROSSOVER-POINT (Null Pointer Dereference) */
          if (sscanf(stonesoup_endptr," %79s",stonesoup_temp_str) == 1) {
            stonesoup_values[stonesoup_i] = ((char *)(malloc((strlen(stonesoup_temp_str) + 1) * sizeof(char ))));
            if (stonesoup_values[stonesoup_i] == 0) {
              stonesoup_printf("Error: Failed to allocate memory\n");
              exit(1);
            }
            strcpy(stonesoup_values[stonesoup_i],stonesoup_temp_str);
            stonesoup_endptr += (strlen(stonesoup_temp_str) + 1) * sizeof(char );
          }
        }
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
        stonesoup_temp = fopen("/opt/stonesoup/workspace/testData/myfile.txt", "w+");
        if(stonesoup_temp != 0) {
          tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
          tracepoint(stonesoup_trace, variable_signed_integral, "stonesoup_len", stonesoup_len, &stonesoup_len, "TRIGGER-STATE");
          for (stonesoup_i = 0; stonesoup_i < stonesoup_len; ++stonesoup_i) {
/* STONESOUP: TRIGGER-POINT (Null Pointer Dereference) */
            tracepoint(stonesoup_trace, variable_buffer, "stonesoup_values[stonesoup_i]", stonesoup_values[stonesoup_i], "TRIGGER-STATE");
            fputs(stonesoup_values[stonesoup_i],stonesoup_temp);
            stonesoup_printf(stonesoup_values[stonesoup_i]);
          }
          tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
          fclose(stonesoup_temp);
        }
        stonesoup_printf("\n");
        for (stonesoup_i = 0; stonesoup_i < stonesoup_len; ++stonesoup_i)
          if (stonesoup_values[stonesoup_i] != 0) {
            free(stonesoup_values[stonesoup_i]);
          }
        if (stonesoup_values != 0) {
          free(stonesoup_values);
        }
      }
      tracepoint(stonesoup_trace, weakness_end);
;
  if (libna_mineralizing . twain_uninductive != 0) 
    free(((char *)libna_mineralizing . twain_uninductive));
stonesoup_close_printf_context();
}
